@@ -49,13 +49,14 @@
 
 package com.openexchange.admin.reseller.rmi.impl;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import com.openexchange.admin.plugins.OXContextPluginInterface;
+import com.openexchange.admin.plugin.hosting.storage.interfaces.OXContextStorageInterface;
 import com.openexchange.admin.plugins.OXContextPluginInterfaceExtended;
 import com.openexchange.admin.plugins.PluginException;
 import com.openexchange.admin.reseller.daemons.ClientAdminThreadExtended;
@@ -79,7 +80,6 @@ import com.openexchange.admin.rmi.exceptions.InvalidDataException;
 import com.openexchange.admin.rmi.exceptions.NoSuchObjectException;
 import com.openexchange.admin.rmi.exceptions.StorageException;
 import com.openexchange.admin.rmi.extensions.OXCommonExtension;
-import com.openexchange.admin.storage.interfaces.OXContextStorageInterface;
 import com.openexchange.admin.storage.interfaces.OXToolStorageInterface;
 import com.openexchange.admin.tools.AdminCache;
 import com.openexchange.tools.pipesnfilters.Filter;
@@ -314,7 +314,7 @@ public class OXResellerContextImpl implements OXContextPluginInterfaceExtended {
         }
 
         try {
-            final MaintenanceReason reason = new MaintenanceReason(42);
+            final MaintenanceReason reason = new MaintenanceReason(I(42));
             final OXContextStorageInterface oxctx = OXContextStorageInterface.getInstance();
             final ResellerAdmin adm = oxresell.getData(new ResellerAdmin[]{new ResellerAdmin(auth.getLogin())})[0];
             oxctx.disableAll(reason, "context2subadmin", "WHERE context2subadmin.cid=context.cid AND context2subadmin.sid=" + adm.getId());
@@ -403,8 +403,8 @@ public class OXResellerContextImpl implements OXContextPluginInterfaceExtended {
 
     /**
      *
-     * @see com.openexchange.admin.plugins.OXContextPluginInterface#list(java.lang.String,
-     * com.openexchange.admin.rmi.dataobjects.Credentials)
+     * @see com.openexchange.admin.plugin.hosting.plugins.OXContextPluginInterface#list(java.lang.String,
+     * com.openexchange.admin.plugin.hosting.rmi.dataobjects.Credentials)
      */
     @Override
     public Filter<Context, Context> list(final String search_pattern, final Credentials auth) throws PluginException {
